srboo.SrbFile

|  | ## Cheshire3 Object Model: Class SrbFile

Module srboo :: Class SrbFile

## Class SrbFile
source code

Object Tree:

    object --+
             |
            SrbFile

Instance Methods

__init__(self, conn, name) x.__init__(...) initializes x; see x.__class__.__doc__ for signature
_connect(self, flag)
_create(self, size, resource, type, path)
fileno(self)
isatty(self)
flush(self)
tell(self)
read(self, size=-1)
close(self)
write(self, value)
seek(self, offset, whence=0)
delete(self, copynum=0)
get_umetadata(self)
set_umetadata(self, f, v)
delete_umetadata(self, f)
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

conn |
fd |
name |
collection |
position |
Inherited from `object`: `__class__`

Method Details

### __init__(self, conn, name) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### _connect(self, flag) | source code

### _create(self, size, resource, type, path) | source code

### fileno(self) | source code

### isatty(self) | source code

### flush(self) | source code

### tell(self) | source code

### read(self, size=-1) | source code

### close(self) | source code

### write(self, value) | source code

### seek(self, offset, whence=0) | source code

### delete(self, copynum=0) | source code

### get_umetadata(self) | source code

### set_umetadata(self, f, v) | source code

### delete_umetadata(self, f) | source code

Class Variable Details

    ### conn Value:
        None

    ### fd Value:
        -1

    ### name Value:
        ""

    ### collection Value:
        ""

    ### position Value:
        0